
/*****************************************************************************
*
* Copyright (C) 2016 Diwell Electronics Co.,Ltd.
* Project Name : (DTS 시리즈) SPI Master Code
* Version : 1.0 (2016.05.04)
* SYSTEM CLOCK : 16Mhz 
* BOARD : Arduino UNO. 5V operation 


 PORT Description

1. ChipSelectPin : 10           
2. MOSI(Master Output) : 11
3. MISO(Master Input) : 12
4. SCK : 13
  온도센서모듈 입력전원은 3.3V로 하셔야 하며 포트 연결 방법은 회로도를 참고하십시오.
  온도센서 통신포트의 논리 레벨은 3.3V 이기 때문에 반드시 회로도를 참고하시기 바랍니다.

 Revision history.

1. 2016.5.4  : First version is released.
****************************************************************************/


#include<SPI.h>

#define TARGET_CMD	0xA0			// 대상 온도 커맨드
#define SENSOR_CMD	0xA1			// 센서 온도 커맨드

const int chipSelectPin  = 10;
unsigned char T_high_byte;
unsigned char T_low_byte;
int  iTARGET, iSENSOR;	// 부호 2byte 온도 저장 변수 

void setup() {
  /* Initalize PORT */
  pinMode(MISO, INPUT);
  pinMode(chipSelectPin , OUTPUT);
  pinMode(MOSI, OUTPUT);
  pinMode(SCK, OUTPUT);
      
  Serial.begin(9600);
  
  /* Setting CS & SPI */
  digitalWrite(chipSelectPin , HIGH);    // CS High Level
  SPI.setDataMode(SPI_MODE3);            // Setting SPI Mode 
  SPI.setClockDivider(SPI_CLOCK_DIV16);  // 16MHz/16 = 1MHz
  SPI.setBitOrder(MSBFIRST);             // MSB First
  SPI.begin();                           // Initialize SPI
  delay(500);                             // wating for DTS setup time 
}
int SEND_COMMAND(unsigned char cCMD)
{
    digitalWrite(chipSelectPin , LOW);  // CS Low Level
    delayMicroseconds(10);              // delay(10us)
    SPI.transfer(cCMD);                // Send 1st Byte
    delay(10);                          // delay(10ms)          
    T_low_byte = SPI.transfer(0x22);   // Send 2nd Byte
    delay(10);                          //delay(10ms)  
    T_high_byte = SPI.transfer(0x22);  // Send 3rd Byte
    digitalWrite(chipSelectPin , HIGH); // CS High Level 
    
    return (T_high_byte<<8 | T_low_byte);	// 상위, 하위 바이트 연산 
}

void loop() {
  // put your main code here, to run repeatedly:
 
  while(1) {
    
    iTARGET = SEND_COMMAND(TARGET_CMD);			// 대상 온도 Read 
    delay(50);					        // 50ms : 이 라인을 지우지 마세요 

    iSENSOR = SEND_COMMAND(SENSOR_CMD);			// 센서 온도 Read
    delay(500);						// 500ms : 이 라인을 지우지 마세요.
    Serial.print("Target Temp : ");
    Serial.print(float(iTARGET)/100);
    Serial.print("     Ambient Temp : ");
    Serial.println(float(iSENSOR)/100);
 
  }
}
